CustomWebSocket class

Constructors

CustomWebSocket(Session session, {HttpClient? customClient})

Properties

customClient ↔ HttpClient?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idJoinRoom ↔ int
getter/setter pair
idLeaveRoom ↔ int
getter/setter pair
idPing ↔ int
getter/setter pair
idPublishVideo ↔ int
getter/setter pair
idsOnIceCandidate → Set<int>
final
idsPrepareReceiveVideo → Map<int, Pair<String, String>>
final
idsReceiveVideo → Map<int, String>
final
mediaServer ↔ String?
getter/setter pair
onErrorEvent ↔ OnErrorEvent?
getter/setter pair
pingMessageInterval → int
final
pingTimer ↔ Timer?
getter/setter pair
rpcId ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → Session
final
webSocket ↔ WebSocket?
getter/setter pair
websocketCancelled ↔ bool
getter/setter pair

Methods

addRemoteParticipantsAlreadyInRoom(Map<String, dynamic> result) → void
Adds remote participants already in the room
changeStreamAudio(String streamId, bool newValue) → void
Sends the changeStreamAudio to the WebSocket server
changeStreamVideo(String streamId, bool newValue) → void
Sends the changeStreamVideo to the WebSocket server
connect() → void
Connects to the WebSocket server
disconnect() → Future<void>
Disconnects from the WebSocket server
getWebSocketAddress() → String
Returns the WebSocket address
handleServerError(Map<String, dynamic> json) → void
Handles the server error
handleServerEvent(Map<String, dynamic> json) → void
Handles the server event
handleServerResponse(Map<String, dynamic> json) → Future<void>
Handles the server response
iceCandidateEvent(Map<String, dynamic> params) → Future<void>
Handles the iceCandidateEvent response
joinRoom() → void
Sends the joinRoom to WebSocket server
leaveRoom() → void
Sends the leaveRoom to WebSocket server
newRemoteParticipantAux(Map<String, dynamic> participantJson) → RemoteParticipant
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConnected() → void
Handles the connection to the WebSocket server
onDisconnected() → void
Handles the disconnection from the WebSocket server
onError(String error) → void
Handles the error from the WebSocket server
onIceCandidate(RTCIceCandidate iceCandidate, String? endpointName) → void
Sends the onIceCandidate to the WebSocket server
onTextMessage(String text) → void
Handles the text message received from the WebSocket server
participantJoinedEvent(Map<String, dynamic> params) → void
participantLeftEvent(Map<String, dynamic> params) → void
participantPublishedEvent(Map<String, dynamic> params) → void
pingMessageHandler() → void
Sends a ping message to the WebSocket server
prepareReceiveVideoFrom(RemoteParticipant remoteParticipant, String streamId) → void
Sends the prepareReceiveVideoFrom to the WebSocket server
publishVideo(RTCSessionDescription sessionDescription) → void
Sends the publishVideo to the WebSocket server
receiveVideoFrom(RTCSessionDescription sessionDescription, RemoteParticipant remoteParticipant, String streamId) → void
Sends the receiveVideoFrom to the WebSocket server
sendJson(String method, [Map<String, dynamic>? params]) → int
Sends a JSON message to the WebSocket server
sendMessage(String message, String nickname) → void
Sends the sendMessage to the WebSocket server
sendMessageEvent(Map<String, dynamic> params) → void
streamPropertyChange({required String streamId, required String property, required dynamic newValue, required String reason}) → void
Sends the streamPropertyChange to the WebSocket server Used to change the audio and video status of a stream
streamPropertyChangedEvent(Map<String, dynamic> params) → void
subscribe(RemoteParticipant remoteParticipant, String streamId) → void
Subscribes to a remote participant
subscriptionInitiatedFromClient(RemoteParticipant remoteParticipant, String streamId) → void
subscriptionInitiatedFromServer(RemoteParticipant remoteParticipant, String streamId) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited