CustomDraggable class

Inheritance

Constructors

CustomDraggable({Key? key, required double initialX, required double initialY, required Widget child, double width = 100.0, double height = 150.0})
Constructor for the CustomDraggable class Takes the initial X and Y positions, the child widget, and optionally the width and height of the widget
const

Properties

child → Widget
The child widget that is to be made draggable
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
The height of the draggable widget
final
initialX → double
The initial X position of the draggable widget
final
initialY → double
The initial Y position of the draggable widget
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
The width of the draggable widget
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomDraggable>
/ Overriding the createState method to return a new instance of _CustomDraggableState
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited